Macros
Internal implemenation of pisserror. These are re-exported by pisserror itself.
In a fair world, this would be done with reflection.
Derive Macros
- Error
- Derives
core::error::Errorfrom special syntax.
Internal implemenation of pisserror. These are re-exported by pisserror itself.
In a fair world, this would be done with reflection.
core::error::Error from special syntax.